# Generated by Django 3.2.13 on 2022-04-27 08:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("pretalx_hitalx", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="expenseitem",
            name="notes",
            field=models.TextField(default=""),
        ),
        migrations.AddField(
            model_name="expenseitem",
            name="reference",
            field=models.URLField(null=True),
        ),
    ]
